Learn R Programming

DeLorean (version 1.2.5)

alpha.for.rug: Calculate a suitable value for a rug plot given the number of points

Description

Calculate a suitable value for a rug plot given the number of points

Usage

alpha.for.rug(n, scale = 100)

Arguments

n

Number of points.

scale

Scale the value.