Learn R Programming

DeLorean (version 1.2.2)

analyse.noise.levels: Analyse noise levels and assess which genes have the greatest ratio of temporal variance to noise. This are labelled as the 'gene.high.psi' genes.

Description

Analyse noise levels and assess which genes have the greatest ratio of temporal variance to noise. This are labelled as the 'gene.high.psi' genes.

Usage

analyse.noise.levels(dl, num.high.psi = 25)

Arguments

dl
de.lorean object
num.high.psi
How many genes with high variance to examine