Rdocumentation
powered by
Learn R Programming
DeLorean (version 1.2.2)
cov.all.genes.conditioned: Calculate covariances for all genes when conditioned on data at estimated pseudotimes.
Description
Calculate covariances for all genes when conditioned on data at estimated pseudotimes.
Usage
cov.all.genes.conditioned(dl, cov.fn = NULL, tau = tau.for.sample(dl))
Arguments
dl
de.lorean object
cov.fn
Covariance function (defaults to cov.matern.32)
tau
The pseudotimes to use