Learn R Programming

DeLorean (version 1.2.2)

cov.calc.gene: Calculate covariance structure for gene over pseudotimes and test inputs.

Description

Calculate covariance structure for gene over pseudotimes and test inputs.

Usage

cov.calc.gene(dl, gene.idx, cov.fn = cov.matern.32,
  tau = tau.for.sample(dl), include.test = TRUE,
  psi = sampled.gene.param(dl, gene.idx, "psi"),
  omega = sampled.gene.param(dl, gene.idx, "omega"))

Arguments

dl
de.lorean object
gene.idx
Gene index
cov.fn
Covariance function (defaults to cov.matern.32)
tau
The pseudotimes to use
include.test
Also include the pseudotimes for the test inputs
psi
Temporal variation
omega
Noise