Learn R Programming

DeLorean (version 1.2.2)

cov.calc.gene.conditioned: Calculate covariance for gene over test inputs when conditioned on data at estimated pseudotimes.

Description

Calculate covariance for gene over test inputs when conditioned on data at estimated pseudotimes.

Usage

cov.calc.gene.conditioned(dl, gene.idx, cov.fn = NULL,
  tau = tau.for.sample(dl))

Arguments

dl
de.lorean object
gene.idx
Gene index
cov.fn
Covariance function (defaults to cov.matern.32)
tau
The pseudotimes to use