Learn R Programming

DeLorean (version 1.2.0)

estimate.capture.cell.sizes: Estimate the cell sizes per capture. Only uses genes that are expressed in more than half the cells.

Description

Estimate the cell sizes per capture. Only uses genes that are expressed in more than half the cells.

Usage

estimate.capture.cell.sizes(expr.l)

Arguments

expr.l
Melted expression values.