Learn R Programming

DeLorean (version 1.2.2)

find.best.tau: Find best tau to initialise chains with by sampling tau from the prior and using empirical Bayes parameter estimates for the other parameters.

Description

Find best tau to initialise chains with by sampling tau from the prior and using empirical Bayes parameter estimates for the other parameters.

Usage

find.best.tau(dl, num.tau.candidates = 6000, num.tau.to.keep = num.cores,
  num.cores = default.num.cores())

Arguments

dl
de.lorean object
num.tau.candidates
How many candidates to examine. Defaults to 6000.
num.tau.to.keep
How many candidates to keep. Defaults to num.cores.
num.cores
Number of cores to run on. Defaults to default.num.cores()