Learn R Programming

DeLorean (version 1.2.2)

find.smooth.tau: Find best order of the samples assuming some smooth GP prior on the expression profiles over this ordering.

Description

Find best order of the samples assuming some smooth GP prior on the expression profiles over this ordering.

Usage

find.smooth.tau(dl, psi = exp(dl$hyper$mu_psi),
  omega = exp(dl$hyper$mu_omega), num.cores = default.num.cores(),
  num.tau.to.try = num.cores, num.tau.to.keep = num.cores,
  method = "metropolis", ...)

Arguments

dl
de.lorean object
psi
Temporal variation
omega
Noise
num.cores
Number of cores to run on. Defaults to default.num.cores()
num.tau.to.try
How many initialisations to try
num.tau.to.keep
How many initialisations to keep
method
Method to use "maximise" or "metropolis"
...
Extra arguments to method