Learn R Programming

DeLorean (version 1.4.1)

ordering.maximise: Find a good ordering in the sense that some function is locally maximised.

Description

Find a good ordering in the sense that some function is locally maximised.

Usage

ordering.maximise(ordering, fn)

Arguments

ordering

The permutation (ordering) to start from.

fn

A function to maximise.