Learn R Programming

DeLorean (version 1.2.2)

test.robustness.de.lorean: Test robustness of pseudotime estimation on subsets of de.lorean object

Description

Test robustness of pseudotime estimation on subsets of de.lorean object

Usage

test.robustness.de.lorean(dl, pieces = 2)

Arguments

dl
de.lorean object
pieces
How many pieces to partition into