Rdocumentation
powered by
Learn R Programming
DeLorean (version 1.2.0)
adjust.by.cell.sizes: Estimate the cell sizes and adjust the expression by cell size.
Description
Estimate the cell sizes and adjust the expression by cell size.
Usage
adjust.by.cell.sizes(dl)
Arguments
dl
de.lorean object.