fit.dl: Perform all the steps necessary to fit the model.
- prepare the data
- compile the model
- find suitable initialisations
- fit the model using the specified method (sampling or variational Bayes)
- process the posterior.
Description
Perform all the steps necessary to fit the model.
- prepare the data
- compile the model
- find suitable initialisations
- fit the model using the specified method (sampling or variational Bayes)
- process the posterior.