Download BDTOPO helper layers for manual georeferencing
get_georef_helpers.RdDownload BDTOPO helper layers for manual georeferencing
Arguments
- x
Object of class
sforsfc- ...
category names to select which helper layers to download:
"hydro": hydrography (nodes, river segments, lake, pond…)"road": roads and railway lines)"infra": linear / point / surface infrastructure"building": building footprints"other": miscellaneous landmarks (e.g. reference points)
- filename
characterorNULL; optional path to a file. If supplied, all downloaded layers are written to a single GeoPackage at this location. Extension is automatically forced to.gpkg.- crs
numericorcharacter; crs to convert layers to, see sf::st_transform
Examples
if (FALSE) { # \dontrun{
library(sf)
x <- read_sf(system.file("extdata/penmarch.shp", package = "happign"))
hydro <- get_georef_helpers(x, "hydro")
all <- get_georef_helpers(x)
gpkg <- tempfile(fileext = ".gpkg")
save_to_gpkg <- get_georef_helpers(x, "road", "hydro", filename = gpkg)
} # }