Rdocumentation
powered by
Learn R Programming
DeLorean (version 1.2.2)
held.out.select.genes: Select held out genes by those with highest variance
Description
Select held out genes by those with highest variance
Usage
held.out.select.genes(dl, expr, num.held.out)
Arguments
dl
de.lorean object
expr
Expression matrix of all genes
num.held.out
Number to select